@@ -1,13 +1,13 @@
-from defusedxml import ElementTree as etree
+from lxml import etree
 from FreeTAKServer.model.SpecificCoT.SendOther import SendOther
-from FreeTAKServer.controllers.SpecificCoTControllers.SendCoTAbstractController import SendCoTAbstractController
+from .SendCoTAbstractController import SendCoTAbstractController
 from FreeTAKServer.controllers.configuration.LoggingConstants import LoggingConstants
 from FreeTAKServer.controllers.CreateLoggerController import CreateLoggerController
 
 loggingConstants = LoggingConstants()
 logger = CreateLoggerController("SendOtherController").getLogger()
 class SendOtherController(SendCoTAbstractController):
-    def __init__(self, RawCoT=None):
+    def __init__(self, RawCoT):
         if type(RawCoT != bytes):
             pass
         else:
@@ -15,44 +15,35 @@ class SendOtherController(SendCoTAbstractController):
         try:
             tempObject = super().Event.Other()
             self.object = SendOther()
-            if RawCoT is not None:
-                xml = RawCoT.xmlString
-                RawCoT.xmlString = etree.tostring(self.filter_CoT(xml))
-                self.fill_object(self.object, tempObject, RawCoT)
-                try:
-                    object = self.getObject()
+            xml = RawCoT.xmlString
+            RawCoT.xmlString = etree.tostring(self.filter_CoT(xml))
+            self.fill_object(self.object, tempObject, RawCoT)
+            try:
+                object = self.getObject()
 
-                except Exception as e:
-                    logger.error("there has been an exception getting object " + str(e))
-                self.Object.setXmlString(xml)
-            else:
-                pass
+            except Exception as e:
+                logger.error("there has been an exception getting object " + str(e))
+            self.Object.setXmlString(xml)
         except Exception as e:
             logger.error("there has been an exception in the creation of an"
                          "Other object " + str(e))
     #this function modifies the CoT so only the marti and point tags are present
     def filter_CoT(self, event):
         try:
-            from xml.etree.ElementTree import Element
             outputEvent = etree.fromstring(event)
             tempDetail = outputEvent.find('detail')
             outputEvent.remove(tempDetail)
             detail = etree.fromstring(event).find('detail')
             try:
                 marti = detail.find('marti')
-                outputDetail = Element('detail')
+                outputDetail = etree.SubElement(outputEvent, 'detail')
                 outputDetail.append(marti)
-                outputEvent.append(outputDetail)
                 print('dest client found')
                 self.object.martiPresent = True
-            except Exception as e:
-                outputDetail = Element('detail')
-                outputEvent.append(outputDetail)
+            except:
+                etree.SubElement(outputEvent, 'detail')
                 print('no dest client found')
 
             return outputEvent
         except Exception as e:
-            print('exception filtering CoT ' + str(e))
-            
-if __name__ == '__main__':
-    SendOtherController().filter_CoT(b'<?xml version="1.0" encoding="UTF-8" standalone="yes"?><event how="m-g" stale="2021-04-07T10:55:27Z" start="2021-04-07T10:54:27Z" time="2021-04-07T10:54:27Z" type="a-h-G-E-V-C" uid="RMA1107" version="2.0"><point ce="10" hae="0" lat="0" le="10" lon="0" /><detail><remarks>Device Moving: false Last Comm: 2020-10-17 07:00:49 Last GPS Fix: 2020-10-17 06:38:36</remarks><track course="338" speed="0.0" /><uid Droid="RMA1107" /><status battery="1" /></detail></event>')
\ No newline at end of file
+            print('exception filtering CoT ' + str(e))
\ No newline at end of file
