@@ -7,15 +7,12 @@ from FreeTAKServer.controllers.CreateLoggerController import CreateLoggerControl
 loggingConstants = LoggingConstants()
 logger = CreateLoggerController("SendInvalidCoTController").getLogger()
 class SendPingController(SendCoTAbstractController):
-    def __init__(self, RawCoT = None):
+    def __init__(self, RawCoT):
         try:
             RawCoT.xmlString = b'<event/>'
             tempObject = super().Event.takPong()
             object = SendTakPong()
-            if RawCoT is not None:
-                self.fill_object(object, tempObject, RawCoT, addToDB=False)
-            else:
-                pass
+            self.fill_object(object, tempObject, RawCoT, addToDB = False)
         except Exception as e:
             logger.error("there has been an exception in"
                          " the creation of a Ping model object " + str(e))
\ No newline at end of file
