@@ -1,19 +1,16 @@
 from .DataPackageServer import FlaskFunctions, Path, dp_directory, os, app, eventlet, const
 from FreeTAKServer.controllers.configuration.LoggingConstants import LoggingConstants
 from FreeTAKServer.controllers.CreateLoggerController import CreateLoggerController
-from FreeTAKServer.controllers.configuration.DataPackageServerConstants import DataPackageServerConstants
-
 loggingConstants = LoggingConstants()
 logger = CreateLoggerController("TCPDataPackageServer").getLogger()
 
 class TCPDataPackageService(FlaskFunctions):
-    def startup(self, ip, port, pipe):
+    def startup(self, ip, port):
         try:
             from eventlet import wsgi
-            global IP, HTTPPORT, PIPE
+            global IP, HTTPPORT
             IP = ip
             HTTPPORT = port
-            PIPE = pipe
             # Make sure the data package directory exists
             if not Path(dp_directory).exists():
                 app.logger.info(f"Creating directory at {str(dp_directory)}")
@@ -23,8 +20,7 @@ class TCPDataPackageService(FlaskFunctions):
             print(HTTPPORT)
             super().setHTTPPORT(HTTPPORT)
             super().setIP(IP)
-            super().setPIPE(PIPE)
-            wsgi.server(eventlet.listen((DataPackageServerConstants().IP, HTTPPORT)), app)
+            wsgi.server(eventlet.listen((IP, HTTPPORT)), app)
 
 
         except Exception as e:
