@@ -1,12 +1,11 @@
-from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModelVariables.FilenameVariables import FilenameVariables as vars
 
-class Filename(FTSProtocolObject):
+class Filename:
     def __init__(self):
         self.INTAG = None
 
     @staticmethod
-    def ExcheckUpdate(INTAG=vars.ExcheckUpdate().INTAG, ):
+    def CreateExCheckTemplate(INTAG=vars.CreateExCheckTemplate().INTAG, ):
         filename = Filename()
 
         filename.setINTAG(INTAG)
