@@ -1,9 +1,9 @@
 class MissionVariables:
 
     @classmethod
-    def ExcheckUpdate(cls):
-        cls.TYPE = 'CHANGE'
-        cls.TOOL = "ExCheck"
+    def CreateExCheckTemplate(cls):
+        cls.TYPE = None
+        cls.TOOL = None
         cls.NAME = None
         cls.AUTHORUID = None
         return cls
